import { Provider } from "@smithy/types";
/**
 * @internal
 */
export type FromStaticConfig<T> = T | (() => T) | Provider<T>;
/**
 * @internal
 */
export declare const fromStatic: <T>(defaultValue: FromStaticConfig<T>) => Provider<T>;
