/**
 * Attempts to extract the name of the variable that the functional selector is looking for.
 * Improves readability over the raw Function.toString() value.
 * @internal
 * @param functionString - function's string representation.
 *
 * @returns constant value used within the function.
 */
export declare function getSelectorName(functionString: string): string;
